#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Biped
# send your bug reports to contact@dotslashplay.it
###

script_version=20240701.1

PLAYIT_COMPATIBILITY_LEVEL='2.29'

GAME_ID='biped'
GAME_NAME='Biped'

ARCHIVE_BASE_0_NAME='setup_biped_1.6_(39586).exe'
ARCHIVE_BASE_0_MD5='c58ee9791defa88ef1bb92ba3b2f01d2'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_biped_1.6_(39586)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='48103181d4c54a068db5eec37e10d7e5'
ARCHIVE_BASE_0_SIZE='6500000'
ARCHIVE_BASE_0_VERSION='1.6-gog39586'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/biped'

UNITY3D_NAME='biped'

CONTENT_PATH_DEFAULT='.'

## FIXME: Add persistent storage for saved games and settings.

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers

launchers_generation 'PKG_BIN'

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
